testcoverage (pygeodesy 26.3.26)

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
pygeodesy/__init__.py | 193 | 4 | 8 | 98%
pygeodesy/albers.py | 408 | 13 | 30 | 97%
pygeodesy/angles.py | 493 | 23 | 27 | 95%
pygeodesy/auxilats/_CX_4.py | 6 | 0 | 0 | 100%
pygeodesy/auxilats/_CX_6.py | 6 | 0 | 0 | 100%
pygeodesy/auxilats/_CX_8.py | 6 | 0 | 0 | 100%
pygeodesy/auxilats/_CX_Rs.py | 84 | 3 | 59 | 96%
pygeodesy/auxilats/__init__.py | 8 | 0 | 0 | 100%
pygeodesy/auxilats/auxAngle.py | 224 | 9 | 33 | 96%
pygeodesy/auxilats/auxDLat.py | 149 | 7 | 10 | 95%
pygeodesy/auxilats/auxDST.py | 98 | 3 | 35 | 97%
pygeodesy/auxilats/auxLat.py | 437 | 31 | 47 | 93%
pygeodesy/auxilats/auxily.py | 108 | 6 | 37 | 94%
pygeodesy/azimuthal.py | 318 | 7 | 55 | 98%
pygeodesy/basics.py | 276 | 34 | 169 | 88%
pygeodesy/booleans.py | 966 | 51 | 145 | 95%
pygeodesy/cartesianBase.py | 322 | 27 | 42 | 92%
pygeodesy/clipy.py | 316 | 14 | 18 | 96%
pygeodesy/constants.py | 221 | 6 | 82 | 97%
pygeodesy/css.py | 234 | 6 | 12 | 97%
pygeodesy/datums.py | 251 | 15 | 9 | 94%
pygeodesy/deprecated/__init__.py | 13 | 0 | 0 | 100%
pygeodesy/deprecated/bases.py | 5 | 0 | 3 | 100%
pygeodesy/deprecated/classes.py | 70 | 2 | 189 | 97%
pygeodesy/deprecated/consterns.py | 20 | 0 | 28 | 100%
pygeodesy/deprecated/datum.py | 7 | 0 | 0 | 100%
pygeodesy/deprecated/functions.py | 42 | 2 | 237 | 95%
pygeodesy/deprecated/nvector.py | 6 | 0 | 6 | 100%
pygeodesy/deprecated/rhumbBase.py | 3 | 0 | 0 | 100%
pygeodesy/deprecated/rhumbaux.py | 4 | 0 | 0 | 100%
pygeodesy/deprecated/rhumbsolve.py | 4 | 0 | 0 | 100%
pygeodesy/deprecated/rhumbx.py | 4 | 0 | 0 | 100%
pygeodesy/dms.py | 298 | 10 | 41 | 97%
pygeodesy/ecef.py | 497 | 27 | 41 | 95%
pygeodesy/ecefLocals.py | 49 | 4 | 2 | 92%
pygeodesy/elevations.py | 69 | 14 | 51 | 80%
pygeodesy/ellipses.py | 404 | 28 | 27 | 93%
pygeodesy/ellipsoidalBase.py | 260 | 15 | 64 | 94%
pygeodesy/ellipsoidalBaseDI.py | 331 | 31 | 25 | 91%
pygeodesy/ellipsoidalExact.py | 42 | 0 | 1 | 100%
pygeodesy/ellipsoidalGeodSolve.py | 39 | 0 | 1 | 100%
pygeodesy/ellipsoidalKarney.py | 40 | 0 | 6 | 100%
pygeodesy/ellipsoidalNvector.py | 134 | 5 | 5 | 96%
pygeodesy/ellipsoidalVincenty.py | 178 | 2 | 11 | 99%
pygeodesy/ellipsoids.py | 766 | 29 | 78 | 96%
pygeodesy/elliptic.py | 564 | 18 | 63 | 97%
pygeodesy/epsg.py | 100 | 2 | 7 | 98%
pygeodesy/errors.py | 332 | 31 | 59 | 91%
pygeodesy/etm.py | 410 | 34 | 115 | 92%
pygeodesy/fmath.py | 339 | 30 | 124 | 91%
pygeodesy/formy.py | 449 | 11 | 25 | 98%
pygeodesy/frechet.py | 261 | 11 | 78 | 96%
pygeodesy/fstats.py | 325 | 6 | 24 | 98%
pygeodesy/fsums.py | 1107 | 54 | 176 | 95%
pygeodesy/gars.py | 144 | 5 | 10 | 97%
pygeodesy/geod3solve.py | 144 | 13 | 30 | 91%
pygeodesy/geodesici.py | 617 | 55 | 373 | 91%
pygeodesy/geodesicw.py | 233 | 22 | 26 | 91%
pygeodesy/geodesicx/_C4_24.py | 6 | 0 | 0 | 100%
pygeodesy/geodesicx/_C4_27.py | 6 | 0 | 0 | 100%
pygeodesy/geodesicx/_C4_30.py | 6 | 0 | 0 | 100%
pygeodesy/geodesicx/__init__.py | 6 | 0 | 0 | 100%
pygeodesy/geodesicx/gx.py | 522 | 39 | 32 | 93%
pygeodesy/geodesicx/gxarea.py | 230 | 16 | 34 | 93%
pygeodesy/geodesicx/gxbases.py | 60 | 4 | 1 | 93%
pygeodesy/geodesicx/gxline.py | 256 | 22 | 29 | 91%
pygeodesy/geodsolve.py | 86 | 2 | 120 | 98%
pygeodesy/geohash.py | 368 | 10 | 42 | 97%
pygeodesy/geoids.py | 688 | 26 | 122 | 96%
pygeodesy/hausdorff.py | 235 | 11 | 57 | 95%
pygeodesy/heights.py | 316 | 15 | 122 | 95%
pygeodesy/internals.py | 275 | 25 | 119 | 91%
pygeodesy/interns.py | 351 | 2 | 19 | 99%
pygeodesy/iters.py | 204 | 7 | 27 | 97%
pygeodesy/karney.py | 362 | 30 | 70 | 92%
pygeodesy/ktm.py | 233 | 11 | 39 | 95%
pygeodesy/latlonBase.py | 475 | 34 | 86 | 93%
pygeodesy/lazily.py | 216 | 9 | 83 | 96%
pygeodesy/lcc.py | 280 | 11 | 23 | 96%
pygeodesy/ltp.py | 419 | 21 | 76 | 95%
pygeodesy/ltpTuples.py | 570 | 29 | 49 | 95%
pygeodesy/mgrs.py | 267 | 2 | 62 | 99%
pygeodesy/named.py | 530 | 21 | 147 | 96%
pygeodesy/namedTuples.py | 262 | 12 | 2 | 95%
pygeodesy/nvectorBase.py | 256 | 13 | 33 | 95%
pygeodesy/osgr.py | 305 | 8 | 65 | 97%
pygeodesy/points.py | 530 | 36 | 100 | 93%
pygeodesy/props.py | 243 | 7 | 64 | 97%
pygeodesy/resections.py | 375 | 11 | 60 | 97%
pygeodesy/rhumb/__init__.py | 10 | 0 | 0 | 100%
pygeodesy/rhumb/aux_.py | 140 | 6 | 2 | 96%
pygeodesy/rhumb/bases.py | 373 | 24 | 116 | 94%
pygeodesy/rhumb/ekx.py | 225 | 4 | 46 | 98%
pygeodesy/rhumb/solve.py | 96 | 8 | 67 | 92%
pygeodesy/simplify.py | 210 | 2 | 3 | 99%
pygeodesy/solveBase.py | 247 | 22 | 40 | 91%
pygeodesy/sphericalBase.py | 250 | 14 | 11 | 94%
pygeodesy/sphericalNvector.py | 317 | 28 | 38 | 91%
pygeodesy/sphericalTrigonometry.py | 388 | 26 | 71 | 93%
pygeodesy/streprs.py | 273 | 15 | 19 | 95%
pygeodesy/trf.py | 622 | 28 | 62 | 95%
pygeodesy/triaxials/__init__.py | 10 | 0 | 0 | 100%
pygeodesy/triaxials/bases.py | 507 | 43 | 16 | 92%
pygeodesy/triaxials/conformal3.py | 272 | 34 | 26 | 88%
pygeodesy/triaxials/triaxial3.py | 424 | 44 | 27 | 90%
pygeodesy/triaxials/triaxial5.py | 429 | 44 | 39 | 90%
pygeodesy/units.py | 305 | 13 | 12 | 96%
pygeodesy/unitsBase.py | 122 | 7 | 9 | 94%
pygeodesy/ups.py | 161 | 5 | 10 | 97%
pygeodesy/utily.py | 342 | 20 | 47 | 94%
pygeodesy/utm.py | 259 | 8 | 21 | 97%
pygeodesy/utmups.py | 87 | 2 | 13 | 98%
pygeodesy/utmupsBase.py | 269 | 5 | 29 | 98%
pygeodesy/vector2d.py | 344 | 8 | 25 | 98%
pygeodesy/vector3d.py | 235 | 8 | 44 | 97%
pygeodesy/vector3dBase.py | 322 | 38 | 165 | 88%
pygeodesy/webmercator.py | 126 | 1 | 18 | 99%
pygeodesy/wgrs.py | 190 | 6 | 9 | 97%
Total | 29927 | 1617 | 5412 | 95%

No items found using the specified filter.